@@ -262,7 +262,7 @@ gg_step <- function(
       dplyr::mutate(dplyr::across(!!col, function(x) factor(x)))
   }
 
-  if (flipped & col_character | col_factor) {
+  if (flipped & (col_character | col_factor)) {
     data <- data %>%
       dplyr::mutate(dplyr::across(!!col, function(x) forcats::fct_rev(x)))
   }
